@@ -1,13 +1,10 @@
 use std::cell::RefCell;
 use std::collections::HashSet;
 use std::io;
-use std::ops::Deref;
 use std::rc::Rc;
 use std::{borrow::Cow, os::unix::prelude::CommandExt};
 
-use crossterm::event::{
-    self, DisableMouseCapture, EnableMouseCapture, Event, KeyCode, KeyModifiers, MouseEventKind,
-};
+use crossterm::event::{self, Event, KeyCode, KeyModifiers};
 use crossterm::execute;
 use crossterm::terminal::{
     disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen,
@@ -31,7 +28,7 @@ enum Mode {
 fn main() -> Result<(), io::Error> {
     enable_raw_mode()?;
     let mut stdout = io::stdout();
-    execute!(stdout, EnterAlternateScreen, EnableMouseCapture)?;
+    execute!(stdout, EnterAlternateScreen)?;
     let backend = CrosstermBackend::new(stdout);
     let mut terminal = Terminal::new(backend)?;
 
@@ -39,6 +36,7 @@ fn main() -> Result<(), io::Error> {
     let results: Rc<RefCell<Vec<String>>> = Rc::new(RefCell::new(Vec::new()));
     let mut mode = Mode::Insert;
     let mut selected = 0;
+    let mut info_scroll = 0;
     let mut info: Rc<RefCell<Vec<Spans>>> = Rc::new(RefCell::new(Vec::new()));
     let mut redraw = true;
 
@@ -70,18 +68,21 @@ fn main() -> Result<(), io::Error> {
                     .constraints([Constraint::Min(3), Constraint::Percentage(100)].as_ref())
                     .split(size);
 
-                let para = Paragraph::new(Spans::from(vec![Span::raw(&*query)]))
-                    .block(
-                        Block::default()
-                            .title(Span::styled(
-                                "parui",
-                                Style::default().add_modifier(Modifier::BOLD),
-                            ))
-                            .title_alignment(Alignment::Center)
-                            .borders(Borders::ALL)
-                            .border_type(BorderType::Rounded),
-                    )
-                    .alignment(Alignment::Left);
+                let para = Paragraph::new(Spans::from(vec![
+                    Span::styled("Search: ", Style::default().add_modifier(Modifier::BOLD)),
+                    Span::raw(&*query),
+                ]))
+                .block(
+                    Block::default()
+                        .title(Span::styled(
+                            "parui",
+                            Style::default().add_modifier(Modifier::BOLD),
+                        ))
+                        .title_alignment(Alignment::Center)
+                        .borders(Borders::ALL)
+                        .border_type(BorderType::Rounded),
+                )
+                .alignment(Alignment::Left);
                 s.render_widget(para, chunks[0]);
 
                 let para = Paragraph::new(format_results(
@@ -110,7 +111,10 @@ fn main() -> Result<(), io::Error> {
                     let no_results = Paragraph::new("No results, try searching for something else")
                         .block(
                             Block::default()
-                                .title("No Results")
+                                .title(Span::styled(
+                                    "No Results",
+                                    Style::default().add_modifier(Modifier::BOLD),
+                                ))
                                 .title_alignment(Alignment::Center)
                                 .borders(Borders::ALL)
                                 .border_type(BorderType::Rounded),
@@ -129,10 +133,12 @@ fn main() -> Result<(), io::Error> {
                     let info = Paragraph::new(if info.borrow().is_empty() {
                         vec![Spans::from(Span::styled(
                             "Press ENTER to show package information",
-                            Style::default().fg(Color::Green),
+                            Style::default()
+                                .fg(Color::Green)
+                                .add_modifier(Modifier::BOLD),
                         ))]
                     } else {
-                        info.borrow().clone()
+                        info.borrow().iter().skip(info_scroll).cloned().collect()
                     })
                     .block(
                         Block::default()
@@ -153,7 +159,7 @@ fn main() -> Result<(), io::Error> {
 
         match mode {
             Mode::Insert => {
-                terminal.set_cursor(query.len() as u16 + 1, 1)?;
+                terminal.set_cursor(query.len() as u16 + 9, 1)?;
             }
             Mode::Select => {
                 terminal.set_cursor(1, line + 4)?;
@@ -180,11 +186,7 @@ fn main() -> Result<(), io::Error> {
                         'c' => {
                             if k.modifiers == KeyModifiers::CONTROL {
                                 disable_raw_mode()?;
-                                execute!(
-                                    terminal.backend_mut(),
-                                    LeaveAlternateScreen,
-                                    DisableMouseCapture
-                                )?;
+                                execute!(terminal.backend_mut(), LeaveAlternateScreen,)?;
                                 terminal.clear()?;
                                 terminal.set_cursor(0, 0)?;
 
@@ -196,7 +198,7 @@ fn main() -> Result<(), io::Error> {
                         'w' => {
                             if k.modifiers == KeyModifiers::CONTROL {
                                 let mut chars = query.chars().rev();
-                                while let Some(c) = chars.next() {
+                                for c in chars.by_ref() {
                                     match c {
                                         ' ' | '-' | '_' => break,
                                         _ => (),
@@ -205,6 +207,9 @@ fn main() -> Result<(), io::Error> {
                                 let chars = chars.rev().collect::<String>();
                                 query = Cow::Owned(chars);
                                 redraw = true;
+                            } else {
+                                query.to_mut().push(c);
+                                redraw = true;
                             }
                         }
                         _ => {
@@ -233,25 +238,40 @@ fn main() -> Result<(), io::Error> {
                 },
                 Mode::Select => match k.code {
                     KeyCode::Up => {
-                        if selected > 0 {
-                            selected -= 1;
-                            info.borrow_mut().clear();
+                        if k.modifiers == KeyModifiers::CONTROL {
+                            if info_scroll > 0 {
+                                info_scroll -= 1;
+                                redraw = true;
+                            }
                         } else {
-                            selected = results.borrow().len() as u16 - 1;
-                            info.borrow_mut().clear();
+                            if selected > 0 {
+                                selected -= 1;
+                                info.borrow_mut().clear();
+                            } else {
+                                selected = results.borrow().len() as u16 - 1;
+                                info.borrow_mut().clear();
+                            }
+                            redraw = true;
                         }
-                        redraw = true;
                     }
                     KeyCode::Down => {
-                        let result_count = results.borrow().len();
-                        if result_count > 1 && selected < result_count as u16 - 1 {
-                            selected += 1;
-                            info.borrow_mut().clear();
+                        if k.modifiers == KeyModifiers::CONTROL {
+                            let info = info.borrow();
+                            if !info.is_empty() {
+                                info_scroll += 1;
+                                redraw = true;
+                            }
                         } else {
-                            selected = 0;
-                            info.borrow_mut().clear();
+                            let result_count = results.borrow().len();
+                            if result_count > 1 && selected < result_count as u16 - 1 {
+                                selected += 1;
+                                info.borrow_mut().clear();
+                            } else {
+                                selected = 0;
+                                info.borrow_mut().clear();
+                            }
+                            redraw = true;
                         }
-                        redraw = true;
                     }
                     KeyCode::Left => {
                         let per_page = size.height - 5;
@@ -276,25 +296,40 @@ fn main() -> Result<(), io::Error> {
                     }
                     KeyCode::Char(c) => match c {
                         'j' => {
-                            if selected > 0 {
-                                selected -= 1;
-                                info.borrow_mut().clear();
+                            if k.modifiers == KeyModifiers::CONTROL {
+                                if info_scroll > 0 {
+                                    info_scroll -= 1;
+                                    redraw = true;
+                                }
                             } else {
-                                selected = results.borrow().len() as u16 - 1;
-                                info.borrow_mut().clear();
+                                if selected > 0 {
+                                    selected -= 1;
+                                    info.borrow_mut().clear();
+                                } else {
+                                    selected = results.borrow().len() as u16 - 1;
+                                    info.borrow_mut().clear();
+                                }
+                                redraw = true;
                             }
-                            redraw = true;
                         }
                         'k' => {
-                            let result_count = results.borrow().len();
-                            if result_count > 1 && selected < result_count as u16 - 1 {
-                                selected += 1;
-                                info.borrow_mut().clear();
+                            if k.modifiers == KeyModifiers::CONTROL {
+                                let info = info.borrow();
+                                if !info.is_empty() {
+                                    info_scroll += 1;
+                                    redraw = true;
+                                }
                             } else {
-                                selected = 0;
-                                info.borrow_mut().clear();
+                                let result_count = results.borrow().len();
+                                if result_count > 1 && selected < result_count as u16 - 1 {
+                                    selected += 1;
+                                    info.borrow_mut().clear();
+                                } else {
+                                    selected = 0;
+                                    info.borrow_mut().clear();
+                                }
+                                redraw = true;
                             }
-                            redraw = true;
                         }
                         'h' => {
                             let size = terminal.size().unwrap();
@@ -320,11 +355,7 @@ fn main() -> Result<(), io::Error> {
                         }
                         'q' => {
                             disable_raw_mode()?;
-                            execute!(
-                                terminal.backend_mut(),
-                                LeaveAlternateScreen,
-                                DisableMouseCapture
-                            )?;
+                            execute!(terminal.backend_mut(), LeaveAlternateScreen,)?;
                             terminal.clear()?;
                             terminal.set_cursor(0, 0)?;
 
@@ -337,11 +368,7 @@ fn main() -> Result<(), io::Error> {
                         'c' => {
                             if k.modifiers == KeyModifiers::CONTROL {
                                 disable_raw_mode()?;
-                                execute!(
-                                    terminal.backend_mut(),
-                                    LeaveAlternateScreen,
-                                    DisableMouseCapture
-                                )?;
+                                execute!(terminal.backend_mut(), LeaveAlternateScreen,)?;
                                 terminal.clear()?;
                                 terminal.set_cursor(0, 0)?;
 
@@ -360,11 +387,7 @@ fn main() -> Result<(), io::Error> {
                         }
                         'R' => {
                             disable_raw_mode()?;
-                            execute!(
-                                terminal.backend_mut(),
-                                LeaveAlternateScreen,
-                                DisableMouseCapture
-                            )?;
+                            execute!(terminal.backend_mut(), LeaveAlternateScreen,)?;
 
                             terminal.clear()?;
                             terminal.set_cursor(0, 0)?;
@@ -388,11 +411,7 @@ fn main() -> Result<(), io::Error> {
                             redraw = true;
                         } else {
                             disable_raw_mode()?;
-                            execute!(
-                                terminal.backend_mut(),
-                                LeaveAlternateScreen,
-                                DisableMouseCapture
-                            )?;
+                            execute!(terminal.backend_mut(), LeaveAlternateScreen,)?;
 
                             terminal.clear()?;
                             terminal.set_cursor(0, 0)?;
@@ -407,34 +426,7 @@ fn main() -> Result<(), io::Error> {
                     _ => redraw = true,
                 },
             },
-            Event::Mouse(m) => {
-                if let Mode::Select = mode {
-                    match m.kind {
-                        MouseEventKind::ScrollDown => {
-                            let result_count = results.borrow().len();
-                            if result_count > 1 && selected < result_count as u16 - 1 {
-                                selected += 1;
-                                info.borrow_mut().clear();
-                            } else {
-                                selected = 0;
-                                info.borrow_mut().clear();
-                            }
-                        }
-                        MouseEventKind::ScrollUp => {
-                            if selected > 0 {
-                                selected -= 1;
-                                info.borrow_mut().clear();
-                            } else {
-                                selected = results.borrow().len() as u16 - 1;
-                                info.borrow_mut().clear();
-                            }
-                        }
-                        _ => (),
-                    }
-                }
-                redraw = true;
-            }
-            Event::Resize(..) => redraw = true,
+            _ => redraw = true,
         }
     }
 }
@@ -455,15 +447,19 @@ fn format_results(
     cached_pages: &mut HashSet<usize>,
 ) -> Vec<Spans<'static>> {
     let index_style = Style::default().fg(Color::Gray);
-    let installed_style = Style::default().fg(Color::Green);
-    let uninstalled_style = Style::default().fg(Color::White);
+    let installed_style = Style::default()
+        .fg(Color::Green)
+        .add_modifier(Modifier::BOLD);
+    let uninstalled_style = Style::default()
+        .fg(Color::LightBlue)
+        .add_modifier(Modifier::BOLD);
     let lines: Rc<Vec<String>> = Rc::new(
         lines
             .borrow()
             .iter()
-            .map(|e| e.clone())
             .skip(skip)
             .take(height - 5)
+            .cloned()
             .collect(),
     );
     is_installed(lines.clone(), skip, installed_cache, cached_pages);
@@ -476,7 +472,7 @@ fn format_results(
             let index = i + skip;
             let index_string = index.to_string();
             Spans::from(vec![
-                Span::styled(index_string.clone(), index_style),
+                Span::styled(index_string, index_style),
                 Span::raw(" ".repeat(pad_to - (index as f32 + 1f32).log10().ceil() as usize + 1)),
                 Span::styled(
                     line.clone(),
@@ -496,13 +492,15 @@ fn get_info(query: &String, index: usize, installed_cache: &HashSet<usize>) -> V
 
     let mut info = vec![Spans::from(Span::styled(
         "Press ENTER again to install this package",
-        Style::default().fg(Color::Green),
+        Style::default()
+            .fg(Color::Green)
+            .add_modifier(Modifier::BOLD),
     ))];
 
     if installed_cache.contains(&index) {
         info.push(Spans::from(Span::styled(
             "Press Shift-R to uninstall this package".to_owned(),
-            Style::default().fg(Color::Red),
+            Style::default().fg(Color::Red).add_modifier(Modifier::BOLD),
         )));
         cmd.arg("-Qi").arg(query);
     } else {
@@ -514,7 +512,18 @@ fn get_info(query: &String, index: usize, installed_cache: &HashSet<usize>) -> V
     let stdout = String::from_utf8(output.stdout).unwrap();
 
     for line in stdout.lines().map(|c| c.to_owned()) {
-        info.push(Spans::from(Span::raw(line)));
+        if line.contains(':') {
+            let (key, value) = line.split_once(':').unwrap();
+            info.push(Spans::from(vec![
+                Span::styled(
+                    key.to_owned() + ":",
+                    Style::default().add_modifier(Modifier::BOLD),
+                ),
+                Span::raw(value.to_owned()),
+            ]));
+        } else {
+            info.push(Spans::from(Span::raw(line.to_owned())));
+        }
     }
 
     info
@@ -532,12 +541,12 @@ fn is_installed(
 
     let mut cmd = std::process::Command::new("paru");
     cmd.arg("-Qq");
-    cmd.args(queries.clone().as_slice());
+    cmd.args(queries.as_slice());
 
     let output = cmd.output().unwrap().stdout;
     let output = String::from_utf8(output).unwrap();
     let mut index;
-    for (i, query) in queries.deref().into_iter().enumerate() {
+    for (i, query) in queries.iter().enumerate() {
         index = i + skip;
         let is_installed = output.includes(&(query.to_owned() + "\n"));
         if is_installed {
